LoadingDialogController class abstract
Controller for managing loading dialogs
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVisible → bool
-
Whether the dialog is currently visible
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stateStream
→ Stream<
LoadingState> -
Stream of loading state changes
no setter
Methods
-
dismiss(
) → void - Dismisses the loading dialog
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateMessage(
String message) → void - Updates the loading message
-
updateProgress(
double progress) → void - Updates the progress (0.0 to 1.0)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited