GlobalDialogButtonStyleConfig class
Global configuration for dialog button styles
This class provides default button styles that can be applied to all dialogs when individual dialog configurations don't specify custom button styles.
Constructors
- GlobalDialogButtonStyleConfig({ButtonStyle? primaryButtonStyle, ButtonStyle? secondaryButtonStyle, ButtonStyle? destructiveButtonStyle, TextStyle? cupertinoTextStyle, TextStyle? cupertinoDestructiveTextStyle, Color? loadingIndicatorColor, double loadingIndicatorSize = 16.0, double loadingIndicatorStrokeWidth = 2.0})
-
Creates a new global dialog button style configuration
const
- GlobalDialogButtonStyleConfig.cupertino()
-
Creates a cupertino design style configuration
factory
- GlobalDialogButtonStyleConfig.material()
-
Creates a material design style configuration
factory
- GlobalDialogButtonStyleConfig.minimal()
-
Creates a minimal style configuration
factory
- GlobalDialogButtonStyleConfig.rounded()
-
Creates a rounded style configuration
factory
Properties
- cupertinoDestructiveTextStyle → TextStyle?
-
Text style for destructive Cupertino dialog actions
final
- cupertinoTextStyle → TextStyle?
-
Text style for Cupertino dialog actions
final
- destructiveButtonStyle → ButtonStyle?
-
Style for destructive action buttons
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadingIndicatorColor → Color?
-
Color for loading indicators
final
- loadingIndicatorSize → double
-
Size of loading indicators
final
- loadingIndicatorStrokeWidth → double
-
Stroke width for loading indicators
final
- primaryButtonStyle → ButtonStyle?
-
Style for primary action buttons (usually ElevatedButton)
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryButtonStyle → ButtonStyle?
-
Style for secondary action buttons (usually TextButton)
final
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter
Methods
-
copyWith(
{ButtonStyle? primaryButtonStyle, ButtonStyle? secondaryButtonStyle, ButtonStyle? destructiveButtonStyle, TextStyle? cupertinoTextStyle, TextStyle? cupertinoDestructiveTextStyle, Color? loadingIndicatorColor, double? loadingIndicatorSize, double? loadingIndicatorStrokeWidth}) → GlobalDialogButtonStyleConfig - Creates a copy of this configuration with the given values updated
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited